## 0.14.1 (2025-12-11)

### Fix

-  [`2256163`](https://github.com/JenspederM/kedro-databricks/commit/2256163d131575449776c2a239ebad4e2d5918dc):  there is no tomlkit>0.14

### Ci

-  [`a68c44f`](https://github.com/JenspederM/kedro-databricks/commit/a68c44f5415b212349a60f92ffa5ee6030204264):  always try to publish when pushed to main

### Other Changes

-  [`dbb82ea`](https://github.com/JenspederM/kedro-databricks/commit/dbb82eac2c9371390d84f354f2cb7eaecf4a9ddf):  update uv lock to latest

[main bbbdfc9] bump: version 0.14.0 → 0.14.1
 3 files changed, 16 insertions(+), 2 deletions(-)

